#========================================================================================
#   Require working connection to internet/google
#   See https://developers.google.com/maps/documentation/geocoding/?hl=en
#   Quick test:
#   http://maps.googleapis.com/maps/api/geocode/json?address=Leutragraben+1+07749+Jena+Germany&sensor=false
#========================================================================================
use strict;
use Test::More tests => 6;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Core::API::PerlTools qw ( fcmp );
use DE_EPAGES::Address::API::GeoData qw ( GetGeoLocation GetGeoData FilterLocation);
use Net::Ping;

use constant GOOGLE_MAPS_API => 'maps.googleapis.com';

sub IsGoogleaAPIReachable {
    my $p = Net::Ping->new('icmp');
    my $IsReachable = $p->ping( GOOGLE_MAPS_API );
    $p->close();

    return $IsReachable ? 1 : 0
}

sub TestGetGeoLocationJena {

    my $hAddr = {
        Street  => 'Leutragraben 1',
        Zipcode => '07743',
        City => 'Jena',
        Country => 'Germany',
    };

    my $hLocation = GetGeoLocation($hAddr);
    ok(_Compare($hLocation, {
          'lat' => '50.92887',
          'lng' => '11.58451'
        } ), 'buro in Jena');
}

sub TestGetGeoLocationZero {

    my $hAddr = {
        Street  => 'aaa 66',
        Zipcode => '666',
        City => 'aaa',
        Country => 'Argentinia',
    };

    my $hLocation = GetGeoLocation($hAddr);
    is($hLocation, undef, 'invalid address -> empty result -> return undef');

    $hAddr = {
        Street  => '',
        Zipcode => '',
        City => '',
        Country => '',
    };

    $hLocation = GetGeoLocation($hAddr);
    is($hLocation, undef, 'empty address -> empty result -> return undef');
}


sub TestGetGeoDataLonden {

    my $hAddr = {
        Street  => 'Linen Hall 162- 168 Regent Street',
        City => 'London, W1B 5TF',
        Country => 'Great Britain',
    };
    my $hLocation = GetGeoData($hAddr, \&FilterLocation);

    ok(_Compare($hLocation, {
          'lat' => '51.5121045',
          'lng' => '-0.1393275'
        } ), 'buro in Londen');
}

sub TestGetGeoDataBarcelona {
     my $hAddr = {
        Street  => 'Diagonal, 435 5-1',
        City => '08036 Barcelona',
        Country => 'Spain',
    };
    my $hLocation = GetGeoData($hAddr, \&FilterLocation);
    is(ref ($hLocation), 'HASH' ,'use GeoData directly with UTF-8 chars' );
    ok(_Compare($hLocation, {
          'lat' => '41.3940805',
          'lng' => '2.1507832'
        } ), 'buro in Barcelona');
}

sub _Compare($$) {
    my ($hGot, $hExpected) = @_;
    my $Precesion = 4;
    if (fcmp($hGot->{lat}, $hExpected->{lat}, $Precesion) == 0 and
    fcmp($hGot->{lng}, $hExpected->{lng}, $Precesion) == 0 ) {
        return 1
    }
    else {
        diag( sprintf("comparing cordinates\nlatitude got: %f expected: %f\nlangitude got: %f expected: %f",
        $hGot->{lat}, $hExpected->{lat}, $hGot->{lng}, $hExpected->{lng}  )  );
        return 0;
    }
}

#========================================================================================
#   MAIN
#========================================================================================

RunScript ( Sub => sub {
    SKIP : {
        skip GOOGLE_MAPS_API . ' is not reachable. Check your internet connection.' unless IsGoogleaAPIReachable();
        TestGetGeoLocationJena();
        TestGetGeoLocationZero();
        TestGetGeoDataLonden();
        TestGetGeoDataBarcelona();
    }
} );