#!perl -w
use Test::More tests => 12;
use strict;
use Data::Dumper;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Dictionary::API::Compare qw ( CompareDictionaryFile CompareTranslationFile );

RunScript(
    'Sub' => sub {
        # CompareDictionaryFile, EPG-30050
        my $aErrors = CompareDictionaryFile('de', 'en', './EPG-30050');
        is(scalar @$aErrors, 2, 'Found 2 differences') or diag Dumper($aErrors);
        isnt($aErrors->[0], $aErrors->[1], '2 different errors occured');
        like($aErrors->[0], qr/EPG-30050\.en\.xml keyword TestcaseJS_Mismatch missing \(difference in JS attribute\)$/, '1 missing keyword');
        like($aErrors->[1], qr/EPG-30050\.en\.xml extra keyword Testcase_Mismatch \(difference in JS attribute\)$/, '1 extra keyword');

        # CompareTranslationFile
        $aErrors = CompareTranslationFile('de', 'en', './Translation.Compare');
        is(scalar @$aErrors, 2, 'Found 2 differences in translation file') or diag Dumper($aErrors);
        isnt($aErrors->[0], $aErrors->[1], '2 different errors occured in translation file');
        like($aErrors->[0], qr/Translation\.Compare\.en\.xml attribute tag ExtraDE missing in object tag \/Classes\/Dictionary\/Test$/, '1 missing keyword in translation file');
        like($aErrors->[1], qr/Translation\.Compare\.en\.xml extra attribute tag ExtraEN in object tag \/Classes\/Dictionary\/Test$/, '1 extra keyword in translation file');

        # missing dictionary files
        $aErrors = CompareDictionaryFile('xx', 'yy', './NonExistant');
        is(scalar @$aErrors, 1, '1 missing dictionary file error') or diag Dumper($aErrors);
        like($aErrors->[0], qr/NonExistant\.yy\.xml missing file/, 'NonExistant.yy.xml missing');

        # missing translation files
        $aErrors = CompareTranslationFile('xx', 'yy', './Translation.NonExistant');
        is(scalar @$aErrors, 1, '1 missing translation file error') or diag Dumper($aErrors);
        like($aErrors->[0], qr/Translation\.NonExistant\.yy\.xml missing file/, 'Translation.NonExistant.yy.xml missing');
    }
);
