#========================================================================================
# package      DE_EPAGES::EPagesJ::t::RestClient
# state        private
#========================================================================================
package DE_EPAGES::EPagesJ::t::RestClient;
use base Test::Class;

use strict;
use warnings;

use JSON;
use Test::More;
use DE_EPAGES::EPagesJ::API::Object::RestClient;
use DE_EPAGES::Core::API::Script qw ( RunScript );

sub test : Test(no_plan) {
    my $self = shift;
    my $Client = DE_EPAGES::EPagesJ::API::Object::RestClient->new(
      'BaseURL'    => 'http://localhost:9091/rs/',
      'Datasource' => 'Store',
      'Resource'   => 'shopGUID',
      'RsBasePath' => 'base',
    );
    is($Client->shopOperationUrl('update')->as_string, 'http://localhost:9091/rs/base/Store/shopGUID/update', 'shopOperationUrl');
    is($Client->baseDatasourceUrl()->as_string, 'http://localhost:9091/rs/base/Store', 'baseDatasourceUrl');
    is($Client->encodeRequest({'a'=>'b'}), encode_json({'a'=>'b'}), 'encodeRequest' );
    is_deeply($Client->decodeResponse('{"a":"b"}'), decode_json('{"a":"b"}'), 'decodeRequest' );
}

sub testWithoutBasePath : Test(no_plan) {
    my $self = shift;
    my $Client = DE_EPAGES::EPagesJ::API::Object::RestClient->new(
      'BaseURL'    => 'http://localhost:9091/rs/',
      'Datasource' => 'Store',
      'Resource'   => 'shopGUID',
    );
    is($Client->shopOperationUrl('update')->as_string, 'http://localhost:9091/rs/Store/shopGUID/update', 'shopOperationUrl without base');
    is($Client->baseDatasourceUrl()->as_string, 'http://localhost:9091/rs/Store', 'baseDatasourceUrl without base');
}

sub testPing : Test(no_plan) {
    my $self = shift;
    my $Client = DE_EPAGES::EPagesJ::API::Object::RestClient->new(
      'BaseURL'    => 'http://localhost:1234567/rs/',
      'Datasource' => 'Store',
      'Resource'   => 'shopGUID',
    );
    ok($Client->ping, 'ping');
}

####### Main ############
RunScript(
    Sub => sub {
        Test::Class->runtests;
      }
);
